<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van SAML MandaatToken in een SOAP Header</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <ns uri="http://www.aortarelease.nl/805/" prefix="ao"/>
    <ns uri="http://schemas.xmlsoap.org/soap/envelope/" prefix="soap"/>
    <ns uri="http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd" prefix="wsse"/>
    <ns uri="urn:oasis:names:tc:SAML:2.0:assertion" prefix="saml"/>
    <ns uri="http://www.w3.org/2000/09/xmldsig#" prefix="xmlds"/>
    <pattern>
        <title>SAML Assertion</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion">
            <assert role="error" test="@Version='2.0'">@Version moet aanwezig en de waarde '2.0' hebben</assert>
            <assert role="error" test="saml:Issuer">Issuer is verplicht</assert>
            <assert role="error" test="xmlds:Signature">Signature in de namespace 'http://www.w3.org/2000/09/xmldsig#' is verplicht</assert>
            <assert role="error" test="saml:Subject">Subject is verplicht</assert>
            <assert role="error" test="saml:Conditions">Conditions is verplicht</assert>
            <assert role="error" test="saml:AttributeStatement">AttributeStatement is verplicht</assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Issuer</title>
        <let name="rolcode" value="concat('urn:IIroot:',//hl7:ControlActProcess/hl7:overseer/hl7:assignedEntity/hl7:id/@root,':IIext:',//hl7:ControlActProcess/hl7:overseer/hl7:assignedEntity/hl7:id/@extension,':',//hl7:ControlActProcess/hl7:overseer/hl7:assignedEntity/hl7:code/@code)"/>
            <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:Advice/saml:Assertion/saml:Issuer">
                <assert role="error" test="text() = $rolcode"
                    >De overseer in het bericht moet overeenkomen met het UZI-nummer en de rolcode van de mandaterende
            </assert>
            </rule>
    </pattern>
    
    <pattern>
        <title>SAML Conditions/AudienceRestrictions</title>
        <let name="messageReceiver" value="concat('urn:IIroot:',//hl7:receiver[1]/hl7:device/hl7:id/@root,':IIext:',//hl7:receiver[1]/hl7:device/hl7:id/@extension)"/>
        <let name="messageSender" value="concat('urn:IIroot:',//hl7:sender[1]/hl7:device/hl7:id/@root,':IIext:',//hl7:sender[1]/hl7:device/hl7:id/@extension)"/>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion/saml:Conditions[1]/saml:AudienceRestriction[1]">
            <assert role="error" test="count(saml:Audience) = 2"
            >Er moeten 2 Audiences zijn. De ZIM en het GBZ</assert>
            <assert role="error" test="saml:Audience[.=$messageReceiver]"
            >Audience ZIM '<value-of select="$messageReceiver"/>' ontbreekt</assert>
            <assert role="error" test="saml:Audience[.=$messageSender]"
            >Audience ZIM '<value-of select="$messageSender"/>' ontbreekt</assert>
          </rule>
    </pattern>
    
    <pattern>
        <title>SAML Conditions</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion/saml:Conditions">
            <assert role="error" test="@NotOnOrAfter"
            >NotOnOrAfter moet gevuld zijn
            </assert>
            <assert role="error" test="@NotBefore"
            >NotBefore moet gevuld zijn
            </assert>         
            <let name="notBefore" value="xs:integer(format-dateTime(xs:dateTime(@NotBefore), '[Y0001][M01][D01][H01][m01][s01]', 'en', (), ()))"/>
            <let name="notOnOrAfter" value="xs:integer(format-dateTime(xs:dateTime(@NotOnOrAfter), '[Y0001][M01][D01][H01][m01][s01]', 'en', (), ()))"/>
            <assert role="error" test="$notOnOrAfter &gt; $notBefore"
                >Datum @NotBefore moet voor @NotOnOrAfter liggen</assert>
            <assert role="error" test="saml:AudienceRestriction"
                >AudienceRestriction is verplicht</assert>  
        </rule>
    </pattern>
    
    <pattern>
    <title>SAML Signature</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion
        /xmlds:Signature">
        <assert role="error" test="xmlds:KeyInfo"
            >Signature/KeyInfo is verplicht</assert>
    </rule>
    </pattern>
    
    <pattern>
        <title>SAML Signature/Reference</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference">
            <assert role="error" test="@URI=concat('#',/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/@ID)"
                >Signature/SignedInfo/Reference/@URI moet verwijzen naar Assertion/@ID</assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Signature/Reference/Transforms</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference/xmlds:Transforms">
            <assert role="error" test="xmlds:Transform[@Algorithm='http://www.w3.org/2000/09/xmldsig#enveloped-signature']"
                >Signature/SignedInfo/Reference/Transforms/Transform/@Algorithm='http://www.w3.org/2000/09/xmldsig#enveloped-signature' is verplicht</assert>
            <assert role="error" test="xmlds:Transform[@Algorithm='http://www.w3.org/2001/10/xml-exc-c14n#']"
                >Signature/SignedInfo/Reference/Transforms/Transform/@Algorithm='http://www.w3.org/2001/10/xml-exc-c14n#' is verplicht</assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Signature/SignedInfo</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion/xmlds:Signature/xmlds:SignedInfo">
            <assert role="error" test="xmlds:SignatureMethod[@Algorithm='http://www.w3.org/2001/04/xmldsig-more#rsa-sha256']"
                >SignatureMethod moet gelijk zijn aan 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha256'</assert>
        </rule>
    </pattern>   
    
    <pattern>
        <title>SAML Signature/SignedInfo/Reference</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference">
            <assert role="error" test="xmlds:DigestMethod[@Algorithm='http://www.w3.org/2001/04/xmlenc#sha256']"
                >SignatureMethod moet gelijk zijn aan 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha256'</assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Subject</title>
        <let name="TransactionOrganisation" value="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Issuer"/>
        <let name="MessageOrganisation" value="concat('urn:IIroot:',//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id/@root,':IIext:',//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id/@extension)"/>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion/saml:Subject">
            <assert role="error" test="saml:NameID[.=$TransactionOrganisation]"  
                >Subject/NameID moet overeenkomen met de Issuer in het transactietoken '<value-of select="$TransactionOrganisation"/>'</assert>
        </rule>
    </pattern>
    
    <pattern>
    <title>SAML AttributeStatement/Attribute (autorisatieregel)</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[not(saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo)]/saml:Advice/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute">
        <assert role="error" test="@Name='autorisatieregel/context'"
        >Er dient een autorisatieregel/context als Attribute te zijn opgenomen
        </assert>
        <assert role="error" test="not(saml:AttributeValue ='')"
        >Er dient een waarde ingevuld te worden bij AttributeValue
        </assert>
    </rule>
    </pattern>
    
</schema>