<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van SAML TransactieToken in een SOAP Header</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <ns uri="http://www.aortarelease.nl/805/" prefix="ao"/>
    <ns uri="http://schemas.xmlsoap.org/soap/envelope/" prefix="soap"/>
    <ns uri="http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd" prefix="wsse"/>
    <ns uri="urn:oasis:names:tc:SAML:2.0:assertion" prefix="saml"/>
    <ns uri="http://www.w3.org/2000/09/xmldsig#" prefix="xmlds"/>
   
    <pattern>
        <title>SAML Assertion</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]">
            <assert role="error" test="@Version='2.0'">@Version moet aanwezig en de waarde '2.0' hebben</assert>
            <assert role="error" test="saml:Issuer">Issuer is verplicht</assert>
            <assert role="error" test="xmlds:Signature">Signature in de namespace 'http://www.w3.org/2000/09/xmldsig#' is verplicht</assert>
            <assert role="error" test="saml:Subject">Subject is verplicht</assert>
            <assert role="error" test="saml:Conditions">Conditions is verplicht</assert>
            <assert role="error" test="saml:AuthnStatement">AuthnStatement is verplicht</assert>
            <assert role="error" test="saml:AttributeStatement">AttributeStatement is verplicht</assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Issuer</title>
        <let name="Organisation" value="concat('urn:IIroot:',//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id/@root,':IIext:',//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id/@extension)"/>        
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Issuer">
            <assert role="error" test="text() = $Organisation"
                >Het transactie is alleen geldig binnen de organisatie vanwaar de authorOrPerformer het bericht verstuurd heeft
            </assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Conditions/AudienceRestrictions</title>
        <let name="messageReceiver" value="concat('urn:IIroot:',//hl7:receiver[1]/hl7:device/hl7:id/@root,':IIext:',//hl7:receiver[1]/hl7:device/hl7:id/@extension)"/>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Conditions[1]/saml:AudienceRestriction[1]">
            <assert role="error" test="saml:Audience[.=$messageReceiver]"
                >Audience ZIM '<value-of select="$messageReceiver"/>' ontbreekt</assert>
        </rule>
    </pattern>
 
    <pattern>
        <title>SAML Conditions</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Conditions">
            <assert role="error" test="@NotOnOrAfter"
                >NotOnOrAfter moet gevuld zijn
            </assert>
            <assert role="error" test="@NotBefore"
                >NotBefore moet gevuld zijn
            </assert>         
            <let name="notBefore2" value="xs:integer(format-dateTime(xs:dateTime(@NotBefore), '[Y0001][M01][D01][H01][m01][s01]', 'en', (), ()))"/>
            <let name="notOnOrAfter2" value="xs:integer(format-dateTime(xs:dateTime(@NotOnOrAfter), '[Y0001][M01][D01][H01][m01][s01]', 'en', (), ()))"/>  
            <assert role="error" test="$notOnOrAfter2 &gt; $notBefore2"
                >Datum @NotBefore moet voor @NotOnOrAfter liggen</assert>
            <assert role="error" test="saml:AudienceRestriction"
                >AudienceRestriction is verplicht</assert>  
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Signature</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature">
            <assert role="error" test="xmlds:KeyInfo"
                >Signature/KeyInfo is verplicht</assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Signature/Reference</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference">
            <assert role="error" test="@URI=concat('#',/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/@ID)"
                >Signature/SignedInfo/Reference/@URI moet verwijzen naar Assertion/@ID</assert>
        </rule>
    </pattern>
   
    <pattern>
        <title>SAML Signature/Reference/Transforms</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference/xmlds:Transforms">
            <assert role="error" test="xmlds:Transform[@Algorithm='http://www.w3.org/2000/09/xmldsig#enveloped-signature']"
                >Signature/SignedInfo/Reference/Transforms/Transform/@Algorithm='http://www.w3.org/2000/09/xmldsig#enveloped-signature' is verplicht</assert>
            <assert role="error" test="xmlds:Transform[@Algorithm='http://www.w3.org/2001/10/xml-exc-c14n#']"
                >Signature/SignedInfo/Reference/Transforms/Transform/@Algorithm='http://www.w3.org/2001/10/xml-exc-c14n#' is verplicht</assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Signature/SignedInfo</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo">
            <assert role="error" test="xmlds:SignatureMethod[@Algorithm='http://www.w3.org/2001/04/xmldsig-more#rsa-sha256']"
                >SignatureMethod moet gelijk zijn aan 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha256'</assert>
        </rule>
    </pattern>   
    
    <pattern>
        <title>SAML Signature/SignedInfo/Reference</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference">
            <assert role="error" test="xmlds:DigestMethod[@Algorithm='http://www.w3.org/2001/04/xmlenc#sha256']"
                >SignatureMethod moet gelijk zijn aan 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha256'</assert>
        </rule>
    </pattern>
    
    <pattern>
        <title>SAML Subject</title>
        <let name="subject" value="concat(//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:id/@extension,':',//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:code/@code)"/>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Subject">
            <assert role="error" test="saml:NameID = $subject"
            >UZI-nummer en rolcode in het bericht moeten overeenkomen met de waardes in het token 
            </assert>
            <assert role="error" test="saml:SubjectConfirmation[@Method='urn:oasis:names:tc:SAML:2.0:cm:holder-of-key']"
                >SubjectConfirmation moet gevuld zijn met urn:oasis:names:tc:SAML:2.0:cm:holder-of-key
            </assert>
            <assert role="error" test="saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo/xmlds:X509Data/xmlds:X509IssuerSerial/xmlds:X509IssuerName"
                >X509Issuername is verplicht
            </assert>
            <assert role="error" test="saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo/xmlds:X509Data/xmlds:X509IssuerSerial/xmlds:X509SerialNumber"
                >X509SerialNumber is verplicht
            </assert>
        </rule>
    </pattern>
         
    <pattern>
        <title>SAML AttributeStatement</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:AttributeStatement[1]">
            <assert role="error" test="saml:Attribute[@Name='burgerServiceNummer']/saml:AttributeValue"
                >Attribute/@Name='burgerServiceNummer' moet zijn meegetekend</assert>
            <assert role="error" test="saml:Attribute[@Name='interactionId']/saml:AttributeValue"
                >Attribute/@Name='interactionId' moet zijn meegetekend</assert>
            <assert role="error" test="saml:Attribute[@Name='messageIdRoot']/saml:AttributeValue"
                >Attribute/@Name='messageIdRoot' moet zijn meegetekend</assert>
            <assert role="error" test="saml:Attribute[@Name='messageIdExt']/saml:AttributeValue"
                >Attribute/@Name='messageIdExt' moet zijn meegetekend</assert>

            <!-- Als er 2 tokens in het bericht zitten dan moet er ook een autorisatieregel zijn opgenomen in het transactietoken 
             oftewel het moet zo zijn dat het altijd waar is dat: er of 1 of minder token in het bericht zitten of dat het er 2 of meer zijn en 
             dat er een autorisatieregel is opgenomen in de transactietoken -->
            
            <assert role="error" test="not(count(/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion) >= 2) or saml:Attribute[@Name='autorisatieregel/context']/saml:AttributeValue" 
                >Attribute/@Name='autorisatieregel/context' moet zijn meegetekend als er ook een mandaattoken is opgenomen in het bericht</assert>
            <assert role="error" test="saml:Attribute[@Name='applicationID']/saml:AttributeValue"
                >Attribute/@Name='applicationID' moet zijn meegetekend</assert>  
            <assert role="error" test="(saml:Attribute[@Name='contextCodeSystem']/saml:AttributeValue and saml:Attribute[@Name='contextCode']/saml:AttributeValue) or (not(saml:Attribute[@Name='contextCodeSystem']/saml:AttributeValue) and (not(saml:Attribute[@Name='contextCode']/saml:AttributeValue)))" 
                >Attribute/@Name='contextCodeSystem' moet zijn meegetekend in het geval er een contextCode is opgenomen.</assert>
            <assert role="error" test="(saml:Attribute[@Name='contextCode']/saml:AttributeValue and //hl7:*[@root='2.16.840.1.113883.1.6']/@extension = 'GQZG_IN000001NL') or ((//hl7:*[@root='2.16.840.1.113883.1.6']/@extension != 'GQZG_IN000001NL') and not(saml:Attribute[@Name='contextCode']/saml:AttributeValue))"
                >Attribute/@Name='contextCode' moet alleen zijn meegetekend in het geval van een generieke query.</assert>
 
        </rule>
        
        <title>SAML AttributeStatement/Attribute (burgerServiceNummer)</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='burgerServiceNummer']/saml:AttributeValue">
            <let name="codeValue" value="text()"/>
            <let name="patientId" value="//hl7:*[@root='2.16.840.1.113883.2.4.6.3']/@extension"/>
            <assert role="error" test=". = $patientId"
                >Attribute burgerServiceNummer '<value-of select="$codeValue"/>' moet overeenkomen met verwachte waarde 
                '<value-of select="$patientId"/>'</assert>
        </rule>
        
        <title>SAML AttributeStatement/Attribute (interactionId)</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='interactionId']/saml:AttributeValue">
            <let name="interactionID" value="//hl7:*[@root='2.16.840.1.113883.1.6']/@extension"/>
            <assert role="error" test=".=$interactionID"
                >Attribute interactionID moet overeenkomen met verwachte waarde '<value-of select="$interactionID"/>'</assert>
        </rule>
        
        <title>SAML AttributeStatement/Attribute (messageIdRoot)</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='messageIdRoot']/saml:AttributeValue">
            <let name="messageIdRoot" value="//hl7:id/@root"/>
            <assert role="error" test="text()=$messageIdRoot"
                >Attribute messageIdRoot moet overeenkomen met verwachte waarde '<value-of select="$messageIdRoot"/>'</assert>
        </rule>
        
        <title>SAML AttributeStatement/Attribute (messageIdExt)</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='messageIdExt']/saml:AttributeValue">
            <let name="messageIdExt" value="//soap:Body/hl7:*/hl7:id/@extension"/>
            <assert role="error" test=".=$messageIdExt"
                >Attribute messageIdExt moet overeenkomen met verwachte waarde '<value-of select="$messageIdExt"/>'</assert>
        </rule>
        
        <title>SAML AttributeStatement/Attribute (applicationID)</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='applicationID']/saml:AttributeValue">
            <let name="applicationID" value="concat('urn:IIroot:',//hl7:sender/hl7:device/hl7:id/@root,':IIext:',//hl7:sender[1]/hl7:device/hl7:id/@extension)"/>
            <assert role="error" test=".=$applicationID"
                >Attribute applicationID moet overeenkomen met verwachte waarde '<value-of select="$applicationID"/>'</assert>
        </rule>
        
        <title>SAML AttributeStatement/Attribute (contextCode)</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='contextCode']/saml:AttributeValue">
            <let name="contextCode" value="//hl7:ControlActProcess/hl7:queryByParameter/hl7:contextCode/hl7:value/@code"/>
            <assert role="error" test=".=$contextCode"
                >Attribute contextCode moet overeenkomen met verwachte waarde '<value-of select="$contextCode"/>'</assert>
        </rule>
     
        <title>SAML AttributeStatement/Attribute (contextCodeSystem)</title>
        <rule context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='contextCodeSystem']/saml:AttributeValue">
            <let name="contextCodeSystem" value="//hl7:ControlActProcess/hl7:queryByParameter/hl7:contextCode/hl7:value/@codeSystem"/>
            <assert role="error" test=".=$contextCodeSystem"
                >Attribute contextCodeSystem moet overeenkomen met verwachte waarde '<value-of select="$contextCodeSystem"/>'</assert>
        </rule>
   
    </pattern>

</schema>
