<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:ao="http://www.aortarelease.nl/805/"
                xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/"
                xmlns:wsse="http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd"
                xmlns:saml="urn:oasis:names:tc:SAML:2.0:assertion"
                xmlns:xmlds="http://www.w3.org/2000/09/xmldsig#"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
<xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


<!--PROLOG-->
<xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl" method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


<!--KEYS AND FUNCTIONS-->


<!--DEFAULT RULES-->


<!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
<!--This mode can be used to generate an ugly though full XPath for locators-->
<xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
<!--This mode can be used to generate prefixed XPath for humans-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
<!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
<xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
<xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
<xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters--><xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
<xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                              title="Schematronvalidatie van SAML TransactieToken in een SOAP Header"
                              schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="urn:hl7-org:v3" prefix="hl7"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.aortarelease.nl/805/" prefix="ao"/>
         <svrl:ns-prefix-in-attribute-values uri="http://schemas.xmlsoap.org/soap/envelope/" prefix="soap"/>
         <svrl:ns-prefix-in-attribute-values uri="http://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-wssecurity-secext-1.0.xsd"
                                             prefix="wsse"/>
         <svrl:ns-prefix-in-attribute-values uri="urn:oasis:names:tc:SAML:2.0:assertion" prefix="saml"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2000/09/xmldsig#" prefix="xmlds"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Assertion</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M8"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Issuer</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M9"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Conditions/AudienceRestrictions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M10"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Conditions</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M11"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Signature</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M12"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Signature/Reference</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M13"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Signature/Reference/Transforms</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M14"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Signature/SignedInfo</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M15"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Signature/SignedInfo/Reference</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M16"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML Subject</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M17"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="name">SAML AttributeStatement/Attribute (contextCodeSystem)</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M18"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">Schematronvalidatie van SAML TransactieToken in een SOAP Header</svrl:text>

   <!--PATTERN SAML Assertion-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Assertion</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]"
                 priority="1000"
                 mode="M8">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@Version='2.0'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@Version='2.0'">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>@Version moet aanwezig en de waarde '2.0' hebben</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:Issuer"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="saml:Issuer">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Issuer is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="xmlds:Signature"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="xmlds:Signature">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Signature in de namespace 'http://www.w3.org/2000/09/xmldsig#' is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:Subject"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="saml:Subject">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Subject is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:Conditions"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="saml:Conditions">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Conditions is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:AuthnStatement"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="saml:AuthnStatement">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>AuthnStatement is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:AttributeStatement"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="saml:AttributeStatement">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>AttributeStatement is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

   <!--PATTERN SAML Issuer-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Issuer</svrl:text>
   <xsl:variable name="Organisation"
                 select="concat('urn:IIroot:',//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id/@root,':IIext:',//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id/@extension)"/>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Issuer"
                 priority="1000"
                 mode="M9">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Issuer"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="text() = $Organisation"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text() = $Organisation">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Het transactie is alleen geldig binnen de organisatie vanwaar de authorOrPerformer het bericht verstuurd heeft
            </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

   <!--PATTERN SAML Conditions/AudienceRestrictions-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Conditions/AudienceRestrictions</svrl:text>
   <xsl:variable name="messageReceiver"
                 select="concat('urn:IIroot:',//hl7:receiver[1]/hl7:device/hl7:id/@root,':IIext:',//hl7:receiver[1]/hl7:device/hl7:id/@extension)"/>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Conditions[1]/saml:AudienceRestriction[1]"
                 priority="1000"
                 mode="M10">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Conditions[1]/saml:AudienceRestriction[1]"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:Audience[.=$messageReceiver]"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="saml:Audience[.=$messageReceiver]">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Audience ZIM '<xsl:text/>
                  <xsl:value-of select="$messageReceiver"/>
                  <xsl:text/>' ontbreekt</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M10"/>
   <xsl:template match="@*|node()" priority="-2" mode="M10">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

   <!--PATTERN SAML Conditions-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Conditions</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Conditions"
                 priority="1000"
                 mode="M11">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Conditions"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@NotOnOrAfter"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@NotOnOrAfter">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>NotOnOrAfter moet gevuld zijn
            </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@NotBefore"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="@NotBefore">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>NotBefore moet gevuld zijn
            </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="notBefore2"
                    select="xs:integer(format-dateTime(xs:dateTime(@NotBefore), '[Y0001][M01][D01][H01][m01][s01]', 'en', (), ()))"/>
      <xsl:variable name="notOnOrAfter2"
                    select="xs:integer(format-dateTime(xs:dateTime(@NotOnOrAfter), '[Y0001][M01][D01][H01][m01][s01]', 'en', (), ()))"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="$notOnOrAfter2 &gt; $notBefore2"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="$notOnOrAfter2 &gt; $notBefore2">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Datum @NotBefore moet voor @NotOnOrAfter liggen</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:AudienceRestriction"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="saml:AudienceRestriction">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>AudienceRestriction is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M11"/>
   <xsl:template match="@*|node()" priority="-2" mode="M11">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

   <!--PATTERN SAML Signature-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Signature</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature"
                 priority="1000"
                 mode="M12">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="xmlds:KeyInfo"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="xmlds:KeyInfo">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Signature/KeyInfo is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

   <!--PATTERN SAML Signature/Reference-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Signature/Reference</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference"
                 priority="1000"
                 mode="M13">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="@URI=concat('#',/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/@ID)"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="@URI=concat('#',/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/@ID)">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Signature/SignedInfo/Reference/@URI moet verwijzen naar Assertion/@ID</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

   <!--PATTERN SAML Signature/Reference/Transforms-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Signature/Reference/Transforms</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference/xmlds:Transforms"
                 priority="1000"
                 mode="M14">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference/xmlds:Transforms"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="xmlds:Transform[@Algorithm='http://www.w3.org/2000/09/xmldsig#enveloped-signature']"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xmlds:Transform[@Algorithm='http://www.w3.org/2000/09/xmldsig#enveloped-signature']">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Signature/SignedInfo/Reference/Transforms/Transform/@Algorithm='http://www.w3.org/2000/09/xmldsig#enveloped-signature' is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="xmlds:Transform[@Algorithm='http://www.w3.org/2001/10/xml-exc-c14n#']"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xmlds:Transform[@Algorithm='http://www.w3.org/2001/10/xml-exc-c14n#']">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Signature/SignedInfo/Reference/Transforms/Transform/@Algorithm='http://www.w3.org/2001/10/xml-exc-c14n#' is verplicht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

   <!--PATTERN SAML Signature/SignedInfo-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Signature/SignedInfo</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo"
                 priority="1000"
                 mode="M15">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="xmlds:SignatureMethod[@Algorithm='http://www.w3.org/2001/04/xmldsig-more#rsa-sha256']"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xmlds:SignatureMethod[@Algorithm='http://www.w3.org/2001/04/xmldsig-more#rsa-sha256']">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>SignatureMethod moet gelijk zijn aan 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha256'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

   <!--PATTERN SAML Signature/SignedInfo/Reference-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Signature/SignedInfo/Reference</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference"
                 priority="1000"
                 mode="M16">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/xmlds:Signature/xmlds:SignedInfo/xmlds:Reference"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="xmlds:DigestMethod[@Algorithm='http://www.w3.org/2001/04/xmlenc#sha256']"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="xmlds:DigestMethod[@Algorithm='http://www.w3.org/2001/04/xmlenc#sha256']">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>SignatureMethod moet gelijk zijn aan 'http://www.w3.org/2001/04/xmldsig-more#rsa-sha256'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M16"/>
   <xsl:template match="@*|node()" priority="-2" mode="M16">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

   <!--PATTERN SAML Subject-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML Subject</svrl:text>
   <xsl:variable name="subject"
                 select="concat(//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:id/@extension,':',//hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:code/@code)"/>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Subject"
                 priority="1000"
                 mode="M17">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:Subject"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:NameID = $subject"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="saml:NameID = $subject">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>UZI-nummer en rolcode in het bericht moeten overeenkomen met de waardes in het token 
            </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:SubjectConfirmation[@Method='urn:oasis:names:tc:SAML:2.0:cm:holder-of-key']"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="saml:SubjectConfirmation[@Method='urn:oasis:names:tc:SAML:2.0:cm:holder-of-key']">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>SubjectConfirmation moet gevuld zijn met urn:oasis:names:tc:SAML:2.0:cm:holder-of-key
            </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo/xmlds:X509Data/xmlds:X509IssuerSerial/xmlds:X509IssuerName"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo/xmlds:X509Data/xmlds:X509IssuerSerial/xmlds:X509IssuerName">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>X509Issuername is verplicht
            </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo/xmlds:X509Data/xmlds:X509IssuerSerial/xmlds:X509SerialNumber"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo/xmlds:X509Data/xmlds:X509IssuerSerial/xmlds:X509SerialNumber">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>X509SerialNumber is verplicht
            </svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M17"/>
   <xsl:template match="@*|node()" priority="-2" mode="M17">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

   <!--PATTERN SAML AttributeStatement SAML AttributeStatement/Attribute (burgerServiceNummer) SAML AttributeStatement/Attribute (interactionId) SAML AttributeStatement/Attribute (messageIdRoot) SAML AttributeStatement/Attribute (messageIdExt) SAML AttributeStatement/Attribute (applicationID) SAML AttributeStatement/Attribute (contextCode) SAML AttributeStatement/Attribute (contextCodeSystem)-->
<svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML AttributeStatement</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:AttributeStatement[1]"
                 priority="1014"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion[saml:Subject/saml:SubjectConfirmation/saml:SubjectConfirmationData/saml:KeyInfo]/saml:AttributeStatement[1]"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:Attribute[@Name='burgerServiceNummer']/saml:AttributeValue"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="saml:Attribute[@Name='burgerServiceNummer']/saml:AttributeValue">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute/@Name='burgerServiceNummer' moet zijn meegetekend</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:Attribute[@Name='interactionId']/saml:AttributeValue"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="saml:Attribute[@Name='interactionId']/saml:AttributeValue">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute/@Name='interactionId' moet zijn meegetekend</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:Attribute[@Name='messageIdRoot']/saml:AttributeValue"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="saml:Attribute[@Name='messageIdRoot']/saml:AttributeValue">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute/@Name='messageIdRoot' moet zijn meegetekend</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:Attribute[@Name='messageIdExt']/saml:AttributeValue"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="saml:Attribute[@Name='messageIdExt']/saml:AttributeValue">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute/@Name='messageIdExt' moet zijn meegetekend</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="not(count(/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion) &gt;= 2) or saml:Attribute[@Name='autorisatieregel/context']/saml:AttributeValue"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="not(count(/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion) &gt;= 2) or saml:Attribute[@Name='autorisatieregel/context']/saml:AttributeValue">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute/@Name='autorisatieregel/context' moet zijn meegetekend als er ook een mandaattoken is opgenomen in het bericht</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="saml:Attribute[@Name='applicationID']/saml:AttributeValue"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="saml:Attribute[@Name='applicationID']/saml:AttributeValue">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute/@Name='applicationID' moet zijn meegetekend</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(saml:Attribute[@Name='contextCodeSystem']/saml:AttributeValue and saml:Attribute[@Name='contextCode']/saml:AttributeValue) or (not(saml:Attribute[@Name='contextCodeSystem']/saml:AttributeValue) and (not(saml:Attribute[@Name='contextCode']/saml:AttributeValue)))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(saml:Attribute[@Name='contextCodeSystem']/saml:AttributeValue and saml:Attribute[@Name='contextCode']/saml:AttributeValue) or (not(saml:Attribute[@Name='contextCodeSystem']/saml:AttributeValue) and (not(saml:Attribute[@Name='contextCode']/saml:AttributeValue)))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute/@Name='contextCodeSystem' moet zijn meegetekend in het geval er een contextCode is opgenomen.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="(saml:Attribute[@Name='contextCode']/saml:AttributeValue and //hl7:*[@root='2.16.840.1.113883.1.6']/@extension = 'GQZG_IN000001NL') or ((//hl7:*[@root='2.16.840.1.113883.1.6']/@extension != 'GQZG_IN000001NL') and not(saml:Attribute[@Name='contextCode']/saml:AttributeValue))"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="(saml:Attribute[@Name='contextCode']/saml:AttributeValue and //hl7:*[@root='2.16.840.1.113883.1.6']/@extension = 'GQZG_IN000001NL') or ((//hl7:*[@root='2.16.840.1.113883.1.6']/@extension != 'GQZG_IN000001NL') and not(saml:Attribute[@Name='contextCode']/saml:AttributeValue))">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute/@Name='contextCode' moet alleen zijn meegetekend in het geval van een generieke query.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML AttributeStatement/Attribute (burgerServiceNummer)</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='burgerServiceNummer']/saml:AttributeValue"
                 priority="1012"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='burgerServiceNummer']/saml:AttributeValue"/>
      <xsl:variable name="codeValue" select="text()"/>
      <xsl:variable name="patientId" select="//hl7:*[@root='2.16.840.1.113883.2.4.6.3']/@extension"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=". = $patientId"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test=". = $patientId">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute burgerServiceNummer '<xsl:text/>
                  <xsl:value-of select="$codeValue"/>
                  <xsl:text/>' moet overeenkomen met verwachte waarde 
                '<xsl:text/>
                  <xsl:value-of select="$patientId"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML AttributeStatement/Attribute (interactionId)</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='interactionId']/saml:AttributeValue"
                 priority="1010"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='interactionId']/saml:AttributeValue"/>
      <xsl:variable name="interactionID" select="//hl7:*[@root='2.16.840.1.113883.1.6']/@extension"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=".=$interactionID"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test=".=$interactionID">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute interactionID moet overeenkomen met verwachte waarde '<xsl:text/>
                  <xsl:value-of select="$interactionID"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML AttributeStatement/Attribute (messageIdRoot)</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='messageIdRoot']/saml:AttributeValue"
                 priority="1008"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='messageIdRoot']/saml:AttributeValue"/>
      <xsl:variable name="messageIdRoot" select="//hl7:id/@root"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test="text()=$messageIdRoot"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="text()=$messageIdRoot">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute messageIdRoot moet overeenkomen met verwachte waarde '<xsl:text/>
                  <xsl:value-of select="$messageIdRoot"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML AttributeStatement/Attribute (messageIdExt)</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='messageIdExt']/saml:AttributeValue"
                 priority="1006"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='messageIdExt']/saml:AttributeValue"/>
      <xsl:variable name="messageIdExt" select="//soap:Body/hl7:*/hl7:id/@extension"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=".=$messageIdExt"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test=".=$messageIdExt">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute messageIdExt moet overeenkomen met verwachte waarde '<xsl:text/>
                  <xsl:value-of select="$messageIdExt"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML AttributeStatement/Attribute (applicationID)</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='applicationID']/saml:AttributeValue"
                 priority="1004"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='applicationID']/saml:AttributeValue"/>
      <xsl:variable name="applicationID"
                    select="concat('urn:IIroot:',//hl7:sender/hl7:device/hl7:id/@root,':IIext:',//hl7:sender[1]/hl7:device/hl7:id/@extension)"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=".=$applicationID"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test=".=$applicationID">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute applicationID moet overeenkomen met verwachte waarde '<xsl:text/>
                  <xsl:value-of select="$applicationID"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML AttributeStatement/Attribute (contextCode)</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='contextCode']/saml:AttributeValue"
                 priority="1002"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='contextCode']/saml:AttributeValue"/>
      <xsl:variable name="contextCode"
                    select="//hl7:ControlActProcess/hl7:queryByParameter/hl7:contextCode/hl7:value/@code"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=".=$contextCode"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test=".=$contextCode">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute contextCode moet overeenkomen met verwachte waarde '<xsl:text/>
                  <xsl:value-of select="$contextCode"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <svrl:text xmlns:svrl="http://purl.oclc.org/dsdl/svrl">SAML AttributeStatement/Attribute (contextCodeSystem)</svrl:text>

	  <!--RULE -->
<xsl:template match="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='contextCodeSystem']/saml:AttributeValue"
                 priority="1000"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="/soap:Envelope/soap:Header[1]/wsse:Security[1]/saml:Assertion/saml:AttributeStatement[1]/saml:Attribute[@Name='contextCodeSystem']/saml:AttributeValue"/>
      <xsl:variable name="contextCodeSystem"
                    select="//hl7:ControlActProcess/hl7:queryByParameter/hl7:contextCode/hl7:value/@codeSystem"/>

		    <!--ASSERT error-->
<xsl:choose>
         <xsl:when test=".=$contextCodeSystem"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test=".=$contextCodeSystem">
               <xsl:attribute name="role">error</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Attribute contextCodeSystem moet overeenkomen met verwachte waarde '<xsl:text/>
                  <xsl:value-of select="$contextCodeSystem"/>
                  <xsl:text/>'</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M18"/>
   <xsl:template match="@*|node()" priority="-2" mode="M18">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
</xsl:stylesheet>